@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Kwiki::Plugin '-Base';
 use Kwiki::Installer '-base';
-our $VERSION = '0.10';
+our $VERSION = '0.12';
 
 const class_id => 'attachments';
 const class_title => 'File Attachments';
@@ -209,12 +209,12 @@ Kwiki::Attachments - Kwiki Page Attachments Plugin
 
 =head1 SYNOPSIS
 
-Install Kwiki::Attachments, then uncomment (or add) 
-the name of this module in your Kwiki's plugins file.
+1. Install Kwiki::Attachments
+2. Run 'kwiki -add Kwiki::Attachments'
 
 =head1 DESCRIPTION
 
-This module gives a Kwiki wiki the ability to store and manage file 
+This module gives a Kwiki wiki the ability to upload, store and manage file
 attachments on any page. 
 
 Depending on the configuration of your web server, you may need to add
@@ -294,7 +294,7 @@ File Attachments For:
 [% END %]
 <tr>
 <td colspan="99">
-<input type="submit" name="Delete" value="Delete"
+<input type="submit" name="Delete" value="Delete">
 </td>
 </tr>
 </table>
